/*
 * Copyright (C) 2020 Damir Porobic <damir.porobic@gmx.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "ImageEffectPickerTest.h"

void ImageEffectPickerTest::TestSelectEffect_Should_EmitSignal_When_EffectChanged()
{
	qRegisterMetaType<ImageEffects>("ImageEffects");
	ImageEffectPicker effectPicker(nullptr);
	QSignalSpy spy(&effectPicker, &ImageEffectPicker::effectSelected);
	auto expectedEffect = ImageEffects::DropShadow;

	effectPicker.setEffect(expectedEffect);

	QCOMPARE(spy.count(), 1);
	auto resultFill = qvariant_cast<ImageEffects>(spy.at(0).at(0));
	QCOMPARE(resultFill, expectedEffect);
}

TEST_MAIN(ImageEffectPickerTest);
